  /****************************************************************************
  * Title                 :   BIG 7 SEG R click
  * Filename              :   Big7SEGPIC.c
  * Author                :   SP
  * Origin Date           :   21/11/2016
  *****************************************************************************/
  /**
  * @note Test configuration:
  * MCU:             P18F87K22
  * Dev.Board:       EasyPIC PRO v7
  * Oscillator:      16 MHz external
  * Ext. Modules:    BIG 7-SEG R Click
  * SW:              PIC v6.6.3
  * NOTES:
    - Place BIG 7-SEG R click board on mikroBUS slot 1
    - PWM: RC1
    - RESET: RC0
    - LATCH: RE0
  *
  /******************************************************************************
  * Includes
  *******************************************************************************/
   #include "7_Seg.h"
  /******************************************************************************
  * Preprocessor Constants
  *******************************************************************************/

  /******************************************************************************
  * Configuration Constants
  *******************************************************************************/

  /******************************************************************************
  * Macros
  *******************************************************************************/

  /******************************************************************************
  * Typedefs
  *******************************************************************************/

  /* Module Variable Definitions
  *******************************************************************************/
  sbit HC595_RES at RC0_bit;
  sbit HC595_LAT at RE0_bit;
  sbit HC595_PWM at RC1_bit;
  /******************************************************************************

  /******************************************************************************
  * Function Definitions
  *******************************************************************************/
  extern char dig_array[MAX_CHARACTERS];

  // Variables
  unsigned short counter;
  unsigned int luminosity;
  unsigned int pwm_period;
  int8_t valid;

  char demo_array[20] =
  { 'M', 'I', 'K', 'R', 'O',
    'E', 'L', 'E', 'K', 'T', 'R', 'O', 'N', 'I', 'K', 'A',
    '2', '0', '1', '6'
  };

  void main()
    {

     TRISE0_bit = 0;                            // Configure PORTA as output
     TRISC0_bit = 0;                            // Configure PORTE as output
     
     LATA = 0;                                  // Initial PORTA value
     LATB = 0;                                  // Initial PORTB value
     LATC = 0;                                  // Initial PORTC value
     LATD = 0;                                  // Initial PORTD value
     LATE = 0;                                  // Initial PORTE value

     // PWM Init
     PWM2_Init(5000);
     PWM2_Set_Duty(10);                         // Set PWM duty
     PWM2_Start();

     // SPI Init
     SPI1_Init_Advanced(_SPI_MASTER_OSC_DIV64, 
                        _SPI_DATA_SAMPLE_END, 
                        _SPI_CLK_IDLE_HIGH, 
                        _SPI_LOW_2_HIGH);

     SPI_Set_Active(SPI1_Read, SPI1_Write);

     Delay_ms(100);

     // 74HC595 Init
     HC595_LAT = 0;
     HC595_RES = 0;
     HC595_reset();

     // Init counter and segment luminosity
     counter = 0;
     luminosity = 0;

     // Endless loop
     while (1)
      {
         valid = seg_7_display(demo_array[counter]);

         PWM2_Set_Duty(50 - luminosity);

         delay_ms(750);
         
         luminosity += 5;
         counter++;

         if (counter == 20)      
           counter = 0;   
         if (luminosity == 50)     
           luminosity = 0;      
      }
}